InstallConfig

Struct InstallConfig 

pub struct InstallConfig { /* private fields */ }
The fixed configuration for a Witchcraft server.

Implementations

Source

impl InstallConfig

pub fn builder() -> Builder<ProductNameStage>

Returns a new builder.

Source

impl InstallConfig

pub fn product_name(&self) -> &str

Returns the service’s name.

Required.

pub fn product_version(&self) -> &str

Returns the service’s version.

Required.

pub fn port(&self) -> u16

Returns the port the server will listen on.

Required.

pub fn management_port(&self) -> Option<u16>

Returns the port that the server’s management APIs will listen on.

Defaults to port().

pub fn keystore(&self) -> &KeystoreConfig

Returns the server’s TLS key configuration.

pub fn client_auth_truststore(&self) -> Option<&ClientAuthTruststoreConfig>

Returns the server’s TLS client authentication truststore configuration.

If set, the server will request (but not require) the client to authenticate itself during the TLS handshake. If a certificate is present and validated against the trust roots, all requests made over that connection will include a ClientCertificate extension.

Defaults to None.

pub fn context_path(&self) -> &str

Returns the server’s context path.

This must either be equal to / or start but not end with a /.

Defaults to /.

pub fn use_console_log(&self) -> bool

If true, the server will log to standard output rather than to files.

Defaults to true if running in a container and false otherwise.

pub fn server(&self) -> &ServerConfig

Returns advanced server settings.

pub fn minidump(&self) -> &MinidumpConfig

Returns minidump settings.