pub struct KeystoreConfig { /* private fields */ }Expand description
TLS key configuration.
Implementations
Sourceimpl KeystoreConfig
impl KeystoreConfig
Sourcepub fn key_path(&self) -> &Path
pub fn key_path(&self) -> &Path
Returns the path to the server’s PEM-encoded private key.
Defaults to var/security/key.pem.
Sourcepub fn cert_path(&self) -> &Path
pub fn cert_path(&self) -> &Path
Returns the path to the server’s PEM-encoded certificate chain.
The file should contain a sequence of certificates starting with the leaf certificate corresponding to the key
in Self::key_path followed by the rest of the certificate chain up to a trusted root.
Defaults to var/security/cert.cer.