pub struct LoggingConfig { /* private fields */ }Expand description
Logging configuration.
Implementations
Sourceimpl LoggingConfig
impl LoggingConfig
Sourcepub fn level(&self) -> LevelFilter
pub fn level(&self) -> LevelFilter
Returns the logging verbosity filter applied globally for all service logs.
Defaults to LevelFilter::Info.
Sourcepub fn loggers(&self) -> &HashMap<String, LevelFilter>
pub fn loggers(&self) -> &HashMap<String, LevelFilter>
Returns a map of verbosity filter overides applied to specific targets.
Sourcepub fn trace_rate(&self) -> f32
pub fn trace_rate(&self) -> f32
Returns the rate at which new traces will be sampled between 0 and 1, inclusive.
This only applies to fresh traces - Witchcraft will respect sampling decisions made by upstream services for a given request.
Defaults to 0.05%.